aboutsummaryrefslogtreecommitdiffstats
path: root/admin/include/image.class.php
diff options
context:
space:
mode:
Diffstat (limited to 'admin/include/image.class.php')
-rw-r--r--admin/include/image.class.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/admin/include/image.class.php b/admin/include/image.class.php
index 86ef35a69..2781ba984 100644
--- a/admin/include/image.class.php
+++ b/admin/include/image.class.php
@@ -265,8 +265,8 @@ class pwg_image
/** Returns a normalized convolution kernel for sharpening*/
static function get_sharpen_matrix($amount)
{
- // Amount should be in the range of 18-10
- $amount = round(abs(-18 + ($amount * 0.08)), 2);
+ // Amount should be in the range of 24-10
+ $amount = round(abs(-24 + ($amount * 0.14)), 2);
$matrix = array
(